"""
Custom log handler for posting errors to errordite (www.errordite.com).

Dependencies: Requests (http://docs.python-requests.org)
"""
__title__ = 'errordite'
__version__ = '0.5.1'
__author__ = 'Hugo Rodger-Brown'
__license__ = 'Simplified BSD License'
__copyright__ = 'Copyright 2013 Hugo Rodger-Brown'
__description__ = 'Errordite exception logging.'

from handlers import ErrorditeHandler
